@@ -13,6 +13,7 @@ typedef Eo Efl_Net_Server_Unix;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief An AF_UNIX server.
  *
@@ -21,8 +22,6 @@ typedef Eo Efl_Net_Server_Unix;
  * must be subject to some special mode or user, change before executing said
  * method, for example by calling umask(2).
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Unix
  */
 #define EFL_NET_SERVER_UNIX_CLASS efl_net_server_unix_class_get()
@@ -42,8 +41,6 @@ EWAPI const Efl_Class *efl_net_server_unix_class_get(void);
  * @param[in] unlink_before_bind If @c true, server will unlink() the path
  * before bind() is called.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Unix
  */
 EOAPI void efl_net_server_unix_unlink_before_bind_set(Eo *obj, Eina_Bool unlink_before_bind);
@@ -61,8 +58,6 @@ EOAPI void efl_net_server_unix_unlink_before_bind_set(Eo *obj, Eina_Bool unlink_
  *
  * @return If @c true, server will unlink() the path before bind() is called.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Unix
  */
 EOAPI Eina_Bool efl_net_server_unix_unlink_before_bind_get(const Eo *obj);
@@ -79,8 +74,6 @@ EOAPI Eina_Bool efl_net_server_unix_unlink_before_bind_get(const Eo *obj);
  * directories. Do nothing if @c false
  * @param[in] mode The file system permissions to use (file mode)
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Unix
  */
 EOAPI void efl_net_server_unix_leading_directories_create_set(Eo *obj, Eina_Bool leading_directories_create, unsigned int mode);
@@ -97,10 +90,9 @@ EOAPI void efl_net_server_unix_leading_directories_create_set(Eo *obj, Eina_Bool
  * directories. Do nothing if @c false
  * @param[out] mode The file system permissions to use (file mode)
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Server_Unix
  */
 EOAPI void efl_net_server_unix_leading_directories_create_get(const Eo *obj, Eina_Bool *leading_directories_create, unsigned int *mode);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
