@@ -4,6 +4,7 @@
 #ifndef _EFL_NET_SSL_TYPES_EOT_TYPES
 #define _EFL_NET_SSL_TYPES_EOT_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Defines how remote peers should be verified.
  *
  * @since 1.19
@@ -18,7 +19,9 @@ typedef enum
   EFL_NET_SSL_VERIFY_MODE_REQUIRED /**< Always verify and fail if certificate
                                     * wasn't provided */
 } Efl_Net_Ssl_Verify_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Defines the SSL/TLS version to use.
  *
@@ -35,11 +38,11 @@ typedef enum
 {
   EFL_NET_SSL_CIPHER_AUTO = 0, /**< The default. Use the best your system
                                 * supports, disables dangerous ciphers */
-  EFL_NET_SSL_CIPHER_SSLV3, /**< SSLv3, insecure and unsupported - DANGEROUS */
   EFL_NET_SSL_CIPHER_TLSV1, /**< TLSv1, secure and widely available */
   EFL_NET_SSL_CIPHER_TLSV1_1, /**< TLSv1.1, secure */
   EFL_NET_SSL_CIPHER_TLSV1_2 /**< TLSv1.2, secure */
 } Efl_Net_Ssl_Cipher;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
