@@ -13,6 +13,7 @@ typedef Eo Efl_Duplicate;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief An interface for duplication of objects.
  *
@@ -38,5 +39,6 @@ EWAPI const Efl_Class *efl_duplicate_interface_get(void);
  * @ingroup Efl_Duplicate
  */
 EOAPI Efl_Duplicate *efl_duplicate(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
