@@ -13,9 +13,8 @@ typedef Eo Efl_Text_Markup;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Markup data that populates the text object's style and format
- *
- * @since 1.21
  *
  * @ingroup Efl_Text_Markup
  */
@@ -29,8 +28,6 @@ EWAPI const Efl_Class *efl_text_markup_interface_get(void);
  * @param[in] obj The object.
  * @param[in] markup The markup-text representation set to this text.
  *
- * @since 1.21
- *
  * @ingroup Efl_Text_Markup
  */
 EOAPI void efl_text_markup_set(Eo *obj, const char *markup);
@@ -42,23 +39,9 @@ EOAPI void efl_text_markup_set(Eo *obj, const char *markup);
  *
  * @return The markup-text representation set to this text.
  *
- * @since 1.21
- *
  * @ingroup Efl_Text_Markup
  */
 EOAPI const char *efl_text_markup_get(const Eo *obj);
-
-/**
- * @brief Inserts a markup text to the text object in a given cursor position
- *
- * @param[in] obj The object.
- * @param[in] cur Cursor position to insert markup
- * @param[in] markup The markup text to insert
- *
- * @since 1.21
- *
- * @ingroup Efl_Text_Markup
- */
-EOAPI void efl_text_markup_cursor_markup_insert(Eo *obj, Efl_Text_Cursor_Cursor *cur, const char *markup);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
