@@ -27,16 +27,6 @@ typedef struct _Efl_Version
   const char *build_id; /**< Contains @c EFL_BUILD_ID. */
 } Efl_Version;
 
-/** This type describes an observable touple
- *
- * @ingroup Efl
- */
-typedef struct _Efl_Observable_Tuple
-{
-  const char *key; /**< Touple key */
-  Eina_Iterator *data; /**< Touple data */
-} Efl_Observable_Tuple;
-
 
 #endif
 
