@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Progressbar_Legacy_Part;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Elementary progressbar internal part class
  *
  * @ingroup Efl_Ui_Progressbar_Legacy_Part
@@ -20,5 +21,6 @@ typedef Eo Efl_Ui_Progressbar_Legacy_Part;
 #define EFL_UI_PROGRESSBAR_LEGACY_PART_CLASS efl_ui_progressbar_legacy_part_class_get()
 
 EWAPI const Efl_Class *efl_ui_progressbar_legacy_part_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
