@@ -31,11 +31,8 @@
  * Elm_Scrollable_Smart_Interface::extern_pan_set.
  */
 
-#ifdef EFL_EO_API_SUPPORT
-#include "elm_pan.eo.h"
-#endif
 #ifndef EFL_NOLEGACY_API_SUPPORT
-#include "elm_pan.eo.legacy.h"
+#include "elm_pan_eo.legacy.h"
 #endif
 
 /**
@@ -46,6 +43,7 @@ struct _Elm_Pan_Smart_Data
 {
    Evas_Object                   *self;
    Evas_Object                   *content;
+   Evas_Object                   *interface_object;
    Evas_Coord                     x, y, w, h;
    Evas_Coord                     content_w, content_h, px, py;
 };
@@ -60,12 +58,7 @@ typedef void      (*Elm_Interface_Scrollable_Resize_Cb)(Evas_Object *obj, Evas_C
 typedef struct _Elm_Scrollable_Smart_Interface_Data
   Elm_Scrollable_Smart_Interface_Data;
 
-#ifdef EFL_EO_API_SUPPORT
 #include "elm_interface_scrollable.eo.h"
-#endif
-#ifndef EFL_NOLEGACY_API_SUPPORT
-#include "elm_interface_scrollable.eo.legacy.h"
-#endif
 
 struct _Elm_Scrollable_Smart_Interface_Data
 {
@@ -82,7 +75,7 @@ struct _Elm_Scrollable_Smart_Interface_Data
 
    Elm_Scroller_Policy           hbar_flags, vbar_flags;
    Elm_Scroller_Single_Direction one_direction_at_a_time;
-   Elm_Scroller_Movement_Block block;
+   Efl_Ui_Scroll_Block           block;
 
    struct
    {
@@ -99,22 +92,20 @@ struct _Elm_Scrollable_Smart_Interface_Data
       struct
       {
          Evas_Coord x, y;
-         double     timestamp, localtimestamp;
+         double     timestamp;
       } history[60];
 
-      struct
-      {
-         double tadd, dxsum, dysum;
-         double est_timestamp_diff;
-      } hist;
+      double est_timestamp_diff;
 
       double          dragged_began_timestamp;
       double          anim_start;
       double          anim_start2;
       double          anim_start3;
+      double          anim_dur;
+
       double          onhold_vx, onhold_vy, onhold_tlast,
                       onhold_vxe, onhold_vye;
-      double          extra_time;
+
       double          last_time_x_wheel;
       double          last_time_y_wheel;
 
@@ -251,7 +242,7 @@ struct _Elm_Scrollable_Smart_Interface_Data
        return __VA_ARGS__;                                                   \
     }
 
-#if defined(EFL_EO_API_SUPPORT) && defined(EFL_BETA_API_SUPPORT)
+#ifdef EFL_BETA_API_SUPPORT
 EAPI void elm_pan_gravity_set(Elm_Pan *, double x, double) EINA_DEPRECATED;
 EAPI void elm_pan_gravity_get(const Elm_Pan *, double *, double *) EINA_DEPRECATED;
 #endif
