@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Animation_Group;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl group animation abstract class
  *
  * @ingroup Efl_Canvas_Animation_Group
@@ -53,5 +54,6 @@ EOAPI void efl_animation_group_animation_del(Eo *obj, Efl_Canvas_Animation *anim
  * @ingroup Efl_Canvas_Animation_Group
  */
 EOAPI Eina_List *efl_animation_group_animations_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
