@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Image_Internal;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl canvas internal image class
  *
  * @ingroup Efl_Canvas_Image_Internal
@@ -20,5 +21,6 @@ typedef Eo Efl_Canvas_Image_Internal;
 #define EFL_CANVAS_IMAGE_INTERNAL_CLASS efl_canvas_image_internal_class_get()
 
 EWAPI const Efl_Class *efl_canvas_image_internal_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
