@@ -13,6 +13,7 @@ typedef Eo Evas_Canvas3D_Mesh;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Evas 3D canvas mesh class
  *
  * @ingroup Evas_Canvas3D_Mesh
@@ -600,5 +601,6 @@ EOAPI void evas_canvas3d_mesh_lod_boundary_set(Eo *obj, Evas_Real near_lod, Evas
  * @ingroup Evas_Canvas3D_Mesh
  */
 EOAPI void evas_canvas3d_mesh_lod_boundary_get(const Eo *obj, Evas_Real *near_lod, Evas_Real *far_lod);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
